@@ -29,7 +29,7 @@ class Repository:
         Session = sessionmaker(bind=self.engine)
         self.session = scoped_session(Session)
   
-    def save(self, entity: any) -> None:
+    def save(self, entity: any) -> any:
         '''
         Description: save a collection of models or a single model
         Arguments: <data> - collection or single model
@@ -50,6 +50,8 @@ class Repository:
 
             entity_type = type(model)
             Log.trace('Saved entity {0} with id {1}', entity_type, model.id)
+
+            return model
         except Exception as e:
             Log.error(f'An error ocurred: {e}')
             Log.error(traceback.format_exc())
