@@ -57,6 +57,8 @@ class Selenium(Scraper):
             options.add_argument("disable-infobars")
             options.add_argument("--disable-extensions")
             options.add_argument('disable-infobars')
+            options.add_experimental_option('useAutomationExtension', False)
+            options.add_experimental_option('excludeSwitches', ['enable-automation'])
 
         window_size = window['size'] if 'size' in window else []
 
